#---------------------------------------
# Definitions for the blueMail Makefile
#---------------------------------------

PREFIX     = /usr/local
BINDIR     = $(PREFIX)/bin
MAN1DIR    = $(PREFIX)/man/man1
MAN5DIR    = $(PREFIX)/man/man5

INSTALL    = install -c
INSTALLBIN = $(INSTALL) -s -m 755
INSTALLMAN = $(INSTALL) -m 644

# With debug:
#OPTS = -g -fno-rtti -pedantic -W -Wall -Wstrict-prototypes -Wmissing-prototypes -Wpointer-arith

# Optimized, no debug:
OPTS = -O2 -fno-rtti -pedantic -W -Wall -Wstrict-prototypes -Wmissing-prototypes -Wpointer-arith

#---------------------------------------------------------------------
# Defaults are for Linux, with ncurses:
# ("." is used as a placeholder)

CURS_HEADER = \<curses.h\>
CURS_INCDIR = .
CURS_LIBDIR = .
LIBS        = -lncurses
RANLIB      = ranlib
RM          = rm -f
SEP         = ;
POST        =
MOPTS       = -fno-exceptions -DUSE_SHADOWS -DSECURE_TEMP # -DFIXSTANDOUT

#CURS_HEADER    (name of the curses header file)
#CURS_INCDIR    (where curses header file can be found)
#CURS_LIBDIR    (where ncurses library can be found)
#LIBS           (library that need to be linked in)
#RANLIB         (ranlib command)
#RM             (delete command)
#SEP            (multi-statement lines separator)
#POST           (any post-processing that should take place)
#MOPTS          (more compiler options)
#
#                USE_SHADOWS: "shadowed" windows
#                SECURE_TEMP: safer way of creating temporary files
#                FIXSTANDOUT: nicer selection bar for list windows

#---------------------------------------------------------------------
# Linux, with PDCurses (aka XCurses) 2.4:

#CURS_HEADER = \<xcurses.h\>
#CURS_INCDIR = /usr/X11R6/include/X11
#CURS_LIBDIR = /usr/X11R6/lib
#LIBS        = -lXCurses -lXaw -lXmu -lXt -lSM -lICE -lXext -lX11 -lXpm
#MOPTS       = -fno-exceptions -DUSE_SHADOWS -DSECURE_TEMP -DXCURSES -DHAVE_PROTO

#---------------------------------------------------------------------
# DJGPP (MSDOS), with PDCurses 2.4:

#LIBS        = -lpdcur
#RM          = del
# use UPX executable packer instead of: strip bmail $(SEP) \
# use PMODE/DJ stub instead of automatically stubbed bmail.exe
#POST        = @$(RM) bmail.exe $(SEP) \
#		upx -qq --best --overlay=strip --coff bmail $(SEP) \
#		copy /b c:\dos\compiler\gc\bin\pmodstub.exe + bmail \
#		BMAIL.EXE >nul $(SEP) \
#		$(RM) bmuncoll.exe $(SEP) \
#		upx -qq --best --overlay=strip --coff bmuncoll $(SEP) \
#		copy /b c:\dos\compiler\gc\bin\pmodstub.exe + bmuncoll \
#		BMUNCOLL.EXE >nul
#MOPTS       = -DUSE_SHADOWS -DSECURE_TEMP -DFIXSTANDOUT

#---------------------------------------------------------------------
# Cygwin (Windows), with PDCurses 2.4:

#LIBS        = /usr/lib/pdcurses.a
#POST        = strip bmail.exe
#MOPTS       = -fno-exceptions -DUSE_SHADOWS -DSECURE_TEMP -DFIXSTANDOUT

#---------------------------------------------------------------------
# NetBSD, with ncurses:

#CURS_INCDIR = /usr/include/ncurses
#CURS_LIBDIR = /usr/local/lib
#MOPTS       = -DUSE_SHADOWS

#---------------------------------------------------------------------
# Solaris, with standard curses:

#LIBS        = -lcurses
#MOPTS       =

#---------------------------------------------------------------------
# EMX (OS/2), with GNU make, and PDCurses 2.3:
# (Note: If you get "g++: Command not found",
# then type "set cxx=gcc" before running make.)

#CURS_INCDIR = /emx/PDCurses-2.3
#LIBS        = /emx/PDCurses-2.3/os2/pdcurses.a
#RANLIB      = ar -s
#RM          = del /n
#SEP         = &&
# (remove "emxbind -s" for a debug executable):
#POST        = emxbind bmail $(SEP) $(RM) bmail $(SEP) emxbind -s bmail
#MOPTS       = -DUSE_SHADOWS
