/*
 * blueMail offline mail reader
 * routines common to more than one driver

 Copyright (c) 2002 Ingo Brueckl <ib@wupperonline.de>

 Distributed under the GNU General Public License.
 For details, see the file COPYING in the parent directory. */

#ifndef ALLDRV_H
#define ALLDRV_H


#include "../bmail.h"


#define SOFT_CR 141

// additional files to be included in bulletin list
#define BL_NOADD    0
#define BL_NEWFILES 1
#define BL_QWK      2


// for mail data stored into text files
#define MAXLINELEN 256


// temporary message index chain to set body[area][letter].pointer
struct MSG_NDX
{
  int area;
  long pointer;
  MSG_NDX *next;
};

// index of personal message msgnum in areas[area]
struct PERSIDX
{
  int area;
  int msgnum;
};

// temporary chain of personal messages to set persIDX[personal_letters]
struct pIDX
{
  PERSIDX persidx;
  pIDX *next;
};


class alldriver
{
  private:
    bmail *bm;
    main_driver *driver;
    char line[MAXLINELEN];
    char *from, *faddr, *to, *subject, *date;

  public:
    alldriver(bmail *, main_driver *);
    ~alldriver();
    void fsc0054(const char *, char, bool *);
    void XTIread(int **, int, const char * = ".xti");
    const char *XTIsave(int **, int, const char*, bool = true);
    char *getFidoAddr(const char *);
    area_header *getReplyArea(const char *, int);
    file_list *unpackReplies(const char *);
    void fidodate(char *, unsigned int, time_t);
    void mimeCharset(const char *, bool *);
    void splitAddress(const char *, int &, int &, int &, int &);
    const char **bulletin_list(const char [][13], int, int);
    bool isQP(const char *);
    long parseHeader(FILE *, long, bool *);
    char *getFrom() const;
    char *getFaddr() const;
    char *getTo() const;
    char *getSubject() const;
    char *getDate() const;
};


#endif
