/*
 * blueMail offline mail reader
 * Blue Wave packet driver

 Copyright (c) 1996 Toth Istvan <stoty@vma.bme.hu>
 Copyright (c) 1998 William McBrine <wmcbrine@clark.net>
 Copyright (c) 2002 Ingo Brueckl <ib@wupperonline.de>

 Distributed under the GNU General Public License.
 For details, see the file COPYING in the parent directory. */

#ifndef BWAVE_H
#define BWAVE_H


#include "../bmail.h"
#include "alldrv.h"

#ifndef BIG_ENDIAN
  #define BIG_ENDIAN
#endif
#include "bluewave.h"


class bwave : public main_driver
{
  private:
    bmail *bm;
    alldriver *alldrv;
    int NAID, NLID, currentArea;
    int maxAreas;
    INF_AREA_INFO *areas;
    PERSIDX *persIDX;
    int persmsgs;
    bool persArea;
    bodytype **body;
    char *letterBody;
    const char **bulletins;
    char packetID[9];
    char error[80];
    unsigned int infHeaderLen, infAreainfoLen, mixStructLen, ftiStructLen;
    unsigned int net, node;
    //bool usesUPL;
    int maxfromto, maxsubject;
    int *mixID, noOfMixRecs;
    MIX_REC *mixRecord;
    FILE *ftiFile, *datFile;

    void setPacketID();
    FILE *openFile(const char *);
    bool readINF();
    bool readMIX();

  public:
    bwave(bmail *);
    ~bwave();
    const char *init();
    int getNoOfAreas();
    area_header *getNextArea();
    void selectArea(int);
    int getNoOfLetters();
    letter_header *getNextLetter();
    const char *getBody(int, int, letter_header *);
    void resetLetters();
    void initMSF(int **);
    int readMSF(int **);
    const char *saveMSF(int **);
    bool isLatin1();
    const char **getBulletins();
    unsigned int getNet() const;         // for access from bwave_reply only
    unsigned int getNode() const;        // for access from bwave_reply only
    const char *getPacketID() const;     // for access from bwave_reply only
};


class bwave_reply : public reply_driver
{
  private:
    bmail *bm;
    bwave *mainDriver;
    alldriver *alldrv;
    int NLID, noOfLetters;
    char *replyBody;
    struct REPLY
    {
      UPL_REC upl;
      const char *filename;
      long length;
      REPLY *next;
    } *firstReply, *currentReply;
    char replyPacketName[13];
    char error[80];

    void replyInf();
    bool putReplies();
    bool put1Reply(FILE *, FILE *, FILE *, REPLY *);
    bool getReplies(const char *);
    bool get1Reply(FILE *, FILE *, FILE *, REPLY *, bool, unsigned int);

  public:
    bwave_reply(bmail *, main_driver *);
    ~bwave_reply();
    const char *init();
    int getNoOfAreas();
    area_header *getNextArea();
    void selectArea(int);
    int getNoOfLetters();
    letter_header *getNextLetter();
    const char *getBody(int, int, letter_header *);
    void resetLetters();
    void initMSF(int **);
    int readMSF(int **);
    const char *saveMSF(int **);
    bool isLatin1();
    const char **getBulletins();
    void enterLetter(letter_header *, const char *, long);
    void killLetter(int);
    const char *newLetterBody(int, long);
    area_header *getArea();
    bool makeReply();
};


#endif
