/*
 * blueMail offline mail reader
 * demonstration driver (will be used for both packet and service)

 Copyright (c) 2002 Ingo Brueckl <ib@wupperonline.de>

 Distributed under the GNU General Public License.
 For details, see the file COPYING in the parent directory. */

#ifndef DEMO_H
#define DEMO_H


#include "../bmail.h"
#include "alldrv.h"


#define PACKETID "demo"
#define DEMO_MAXFROMTO  35
#define DEMO_MAXSUBJECT 71


class demo : public main_driver
{
  private:
    bmail *bm;
    alldriver *alldrv;
    int NAID, NLID, currentArea;
    int maxAreas;
    PERSIDX *persIDX;
    int persmsgs;
    bool persArea;
    bodytype **body;
    char *letterBody;

    int totmsgs, infomsglen;
    char *me, *you, *Demo, *info;

  public:
    demo(bmail *);
    ~demo();
    const char *init();
    int getNoOfAreas();
    area_header *getNextArea();
    void selectArea(int);
    int getNoOfLetters();
    letter_header *getNextLetter();
    const char *getBody(int, int, letter_header *);
    void resetLetters();
    void initMSF(int **);
    int readMSF(int **);
    const char *saveMSF(int **);
    bool isLatin1();
    const char **getBulletins();
    int persOffset() const;              // for access from demo_reply only
};


class demo_reply : public reply_driver
{
  private:
    bmail *bm;
    demo *mainDriver;
    bool service;
    alldriver *alldrv;
    int NLID, noOfLetters;
    char *replyBody;
    struct REPLY
    {
      struct
      {
        char from[DEMO_MAXFROMTO + 1];
        char to[DEMO_MAXFROMTO + 1];
        char subject[DEMO_MAXSUBJECT + 1];
        char date[24];
      } header;
      const char *filename;
      long length;
      REPLY *next;
    } *firstReply, *currentReply;
    char replyPacketName[13];
    char error[80];

    void replyInf();
    bool putReplies();
    bool put1Reply(FILE *, REPLY *);
    bool getReplies(const char *);
    bool get1Reply(FILE *, REPLY *);

  public:
    demo_reply(bmail *, main_driver *);
    ~demo_reply();
    const char *init();
    int getNoOfAreas();
    area_header *getNextArea();
    void selectArea(int);
    int getNoOfLetters();
    letter_header *getNextLetter();
    const char *getBody(int, int, letter_header *);
    void resetLetters();
    void initMSF(int **);
    int readMSF(int **);
    const char *saveMSF(int **);
    bool isLatin1();
    const char **getBulletins();
    void enterLetter(letter_header *, const char *, long);
    void killLetter(int);
    const char *newLetterBody(int, long);
    area_header *getArea();
    bool makeReply();
};


#endif
