/*
 * blueMail offline mail reader
 * color handling

 Copyright (c) 1996 John Zero <john@graphisoft.hu>
 Copyright (c) 1998 William McBrine <wmcbrine@clark.net>
 Copyright (c) 2002 Ingo Brueckl <ib@wupperonline.de>

 Distributed under the GNU General Public License.
 For details, see the file COPYING in the parent directory. */

#ifndef COLOR_H
#define COLOR_H


#include "wincurs.h"


// this is how we internally represent a color (pair)
// (blueMail internal color type as used in bmcolors)
#define COL(f, b) (((f) << 3) + (b))


#define C_MBORDER        color[0]      // main screen border
#define C_MBACK          color[1]      // main screen background
#define C_MSEPBOTT       color[2]      // main screen separator (bottom)
#define C_WELCBORDER     color[3]      // welcome border
#define C_WELCHEADER     color[4]      // welcome header
#define C_WELCTEXT       color[5]      // welcome text
#define C_HELPBORDER     color[6]      // help border
#define C_HELPTEXT       color[7]      // help text
#define C_HELPKEYS       color[8]      // help keys
#define C_HELPDESCR      color[9]      // help descriptions
#define C_SLBORDER       color[10]     // service list border
#define C_SLTOPTEXT      color[11]     // service list top border text
#define C_SLIST          color[12]     // service list
#define C_PLBORDER       color[13]     // packet list border
#define C_PLHEADER       color[14]     // packet list header
#define C_PLIST          color[15]     // packet list
#define C_REPMLBORDER    color[16]     // reply manager list border
#define C_REPMLHEADER    color[17]     // reply manager list header
#define C_REPMLIST       color[18]     // reply manager list
#define C_REPMLPACKET    color[19]     // reply manager list packet
#define C_ALBORDER       color[20]     // area list border
#define C_ALTOPTEXT      color[21]     // area list top border text
#define C_ALHEADER       color[22]     // area list header
#define C_ALISTUNRD      color[23]     // area list Unread
#define C_ALISTREAD      color[24]     // area list Read
#define C_ALREPLY        color[25]     // area list reply area
#define C_ALINFODESCR    color[26]     // area list info win description
#define C_ALINFOTEXT     color[27]     // area list info win text
#define C_BULLLBORDER    color[28]     // bulletin list border
#define C_BULLLTOPTEXT   color[29]     // bulletin list top border text
#define C_BULLLIST       color[30]     // bulletin list
#define C_LALBORDER      color[31]     // little area border
#define C_LALTOPTEXT     color[32]     // little area top border text
#define C_LALIST         color[33]     // little area list
#define C_LALISTRO       color[34]     // little area list read-only
#define C_LLBORDER       color[35]     // letter list border
#define C_LLTOPTEXT      color[36]     // letter list top border text
#define C_LLAREA         color[37]     // letter list areaname
#define C_LLHEADER       color[38]     // letter list header
#define C_LLISTUNRD      color[39]     // letter list Unread
#define C_LLISTREAD      color[40]     // letter list Read
#define C_LLFROMUSER     color[41]     // letter list from user
#define C_LLTOUSER       color[42]     // letter list to user
#define C_LHBORDER       color[43]     // letter header border
#define C_LHMSGNUM       color[44]     // letter header MSGNUM
#define C_LHTEXT         color[45]     // letter header (text)
#define C_LHFROM         color[46]     // letter header FROM
#define C_LHTO           color[47]     // letter header TO
#define C_LHSUBJ         color[48]     // letter header SUBJECT
#define C_LHDATE         color[49]     // letter header DATE
#define C_LHFLAGS        color[50]     // letter header flags
#define C_LHFLAGSHI      color[51]     // letter header flags high
#define C_LTEXT          color[52]     // letter text
#define C_LQTEXT         color[53]     // letter quoted text
#define C_LTAGLINE       color[54]     // letter tagline
#define C_LSIGNATURE     color[55]     // letter signature
#define C_LTEARLINE      color[56]     // letter tearline
#define C_LORIGIN        color[57]     // letter origin
#define C_LKLUDGE        color[58]     // letter kludge line
#define C_LBOTTLINE      color[59]     // letter bottom (status) line
#define C_ANSIVHEADER    color[60]     // ANSI viewer header
#define C_ANSIVIEW       color[61]     // ANSI viewer
#define C_REPBOXBORDER   color[62]     // reply box border
#define C_REPBOXDESCR    color[63]     // reply box description
#define C_REPBOXTEXT     color[64]     // reply box text
#define C_REPBOXINP      color[65]     // reply box input
#define C_REPBOXHELP     color[66]     // reply box help text
#define C_SAVEBOXBORDER  color[67]     // save box border
#define C_SAVEBOXHEADER  color[68]     // save box header
#define C_SAVEBOXINP     color[69]     // save box input
#define C_QUERYBOXBORDER color[70]     // query box border
#define C_QUERYBOXHEADER color[71]     // query box header
#define C_QUERYBOXINP    color[72]     // query box input
#define C_ADDRBKBORDER   color[73]     // addressbook border
#define C_ADDRBKTOPTEXT  color[74]     // addressbook top border text
#define C_ADDRBKHEADER   color[75]     // addressbook header
#define C_ADDRBKLIST     color[76]     // addressbook list
#define C_ADDRBKINP      color[77]     // addressbook input
#define C_ADDRBKKEYS     color[78]     // addressbook (help) keys
#define C_ADDRBKDESCR    color[79]     // addressbook (help) description
#define C_TAGBOXBORDER   color[80]     // tagline box border
#define C_TAGBOXTTEXT    color[81]     // tagline box top border text
#define C_TAGBOXLIST     color[82]     // tagline box list
#define C_TAGBOXINP      color[83]     // tagline box input
#define C_TAGBOXKEYS     color[84]     // tagline box keys
#define C_TAGBOXDESCR    color[85]     // tagline box keys description
#define C_WARNTEXT       color[86]     // warning text
#define C_WARNKEYS       color[87]     // warning text highlighted keys
#define C_INFOTEXT       color[88]     // info text
#define C_SYSCALLHEAD    color[89]     // system call header
#define C_SEARCHRESULT   color[90]     // search results
#define C_SHADOW         color[91]     // shadow for all windows


extern const chtype *color;


class Color
{
  private:
    static chtype bmcolors[];

    chtype colors(const char *, const chtype);

  public:
    Color();
    chtype getBackground() const;
    void convert(UserInterface *);
};


#endif
