/*
 * blueMail offline mail reader
 * help windows

 Copyright (c) 1996 Kolossvary Tamas <thomas@vma.bme.hu>
 Copyright (c) 1998 William McBrine <wmcbrine@clark.net>
 Copyright (c) 2002 Ingo Brueckl <ib@wupperonline.de>

 Distributed under the GNU General Public License.
 For details, see the file COPYING in the parent directory. */


#include <string.h>
#include "interfac.h"
#include "../common/auxil.h"


void HelpWindow::newHelpMenu (const char **keys, const char **func)
{
  int y, z;
  int l, max_l = 0, max_m = 0, max_r = 0;

  menu = new Win(3, COLS - 2, LINES - 4, 1, C_HELPDESCR);

  for (z = -1, y = 0; y < 3; y++)
  {
    if ((l = slen(keys[++z]) + slen(func[z])) > max_l) max_l = l;
    if ((l = slen(keys[++z]) + slen(func[z])) > max_m) max_m = l;
    if ((l = slen(keys[++z]) + slen(func[z])) > max_r) max_r = l;
  }

  midpos = interface->midpos(2, max_l, max_m, max_r);
  endpos = interface->endpos(2, max_r);

  menu->attrib(C_HELPKEYS);

  for (z = -1, y = 0; y < 3; y++)
  {
    if (keys[++z]) menu->putstring(y, 1, keys[z]);
    if (keys[++z]) menu->putstring(y, midpos, keys[z]);
    if (keys[++z]) menu->putstring(y, endpos, keys[z]);
  }

  menu->attrib(C_HELPDESCR);

  for (z = -1, y = 0; y < 3; y++)
  {
    if (func[++z]) menu->putstring(y, 1 + strlen(keys[z]), func[z]);
    if (func[++z]) menu->putstring(y, midpos + strlen(keys[z]), func[z]);
    if (func[++z]) menu->putstring(y, endpos + strlen(keys[z]), func[z]);
  }
}


void HelpWindow::h_servicelist ()
{
  static const char *keys[] =
  {
    "A", "F", NULL,
    NULL, "P", NULL,
    NULL, "R", "Q"
  },
  *func[] =
  {
    ": Addressbook", ": Files/databases", NULL,
    NULL, ": Packets", NULL,
    NULL, ": Replies", ": Quit " BM_NAME
  };

  newHelpMenu(keys, func);

  if (!bm.resourceObject->isYes(OmitDemoService))
  {
    menu->attrib(C_HELPKEYS);
    menu->putstring(2, 1, "D");
    menu->attrib(C_HELPDESCR);
    menu->putstring(2, 2, ": Demo");
  }

  menu->delay_update();
}


void HelpWindow::h_packetlist ()
{
  static const char *keys[] =
  {
    "A", NULL, NULL,
    "K", NULL, NULL,
    "O", NULL, "Q"
  },
  *func[] =
  {
    ": Addressbook", NULL, NULL,
    ": Kill packet", NULL, NULL,
    ": change sort Order", NULL, ": Back to service list"
  };

  newHelpMenu(keys, func);
  menu->delay_update();
}


void HelpWindow::h_filedblist ()
{
  static const char *keys[] =
  {
    "A", NULL, NULL,
    NULL, NULL, NULL,
    NULL, NULL, "Q"
  },
  *func[] =
  {
    ": Addressbook", NULL, NULL,
    NULL, NULL, NULL,
    NULL, NULL, ": Back to service list"
  };

  newHelpMenu(keys, func);
  menu->delay_update();
}


void HelpWindow::h_replymgrlist ()
{
  static const char *keys[] =
  {
    "A", NULL, NULL,
    "K", NULL, NULL,
    "O", NULL, "Q"
  },
  *func[] =
  {
    ": Addressbook", NULL, NULL,
    ": Kill file", NULL, NULL,
    ": change sort Order", NULL, ": Back to service list"
  };

  newHelpMenu(keys, func);
  menu->delay_update();
}


void HelpWindow::h_arealist ()
{
  static const char *keys[] =
  {
    "A", "I", NULL,
    "B", "L", NULL,
    "E", NULL, "Q"
  },
  *func[] =
  {
    ": Addressbook", ": toggle area Info", NULL,
    ": Bulletins", ": Long/short area list", NULL,
    ": Enter letter in area", NULL, ": Back to service(s)"
  };

  newHelpMenu(keys, func);

  midpos = interface->midpos(2, 23, 23, 21);
  endpos = interface->endpos(2, 21);
  // 23 is max length of all strings (left column) above
  // 23 is max length of all strings (middle column) above and below
  // 21 is max length of all strings (right column) above and below

  if (bm.resourceObject->isYes(SkipLetterList))
  {
    menu->attrib(C_HELPKEYS);
    menu->putstring(2, midpos, "S");
    menu->attrib(C_HELPDESCR);
    menu->putstring(2, midpos + 1, ": Show letter list");
  }

  if (bm.driverList->canReply())
  {
    int current_area = bm.areaList->getAreaNo();

    // if replies are possible, REPLY_AREA is area number 0
    bm.areaList->gotoArea(0);

    if (bm.areaList->getNoOfLetters())
    {
      menu->attrib(C_HELPKEYS);
      menu->putstring(0, endpos, "!");
      menu->attrib(C_HELPDESCR);
      menu->putstring(0, endpos + 1, ": save replies now");
    }

    bm.areaList->gotoArea(current_area);   // restore
  }

  menu->delay_update();
}


void HelpWindow::h_letterlist ()
{
  static const char *keys[] =
  {
    // special treatment for indices 1, 2 and 4
    "A", NULL, NULL,
    "E", NULL, NULL,
    "L", "S", "Q"
  },
  *func[] =
  {
    // special treatment for indices 1, 2 and 4
    ": Addressbook", NULL, NULL,
    ": Enter letter in area", NULL, NULL,
    ": List all/unread", ": Save messages", ": Back to area list"
  },
  *repkeys[] =
  {
    "A", "K", NULL,
    "D", "S", NULL,
    "E", NULL, "Q"
  },
  *repfunc[] =
  {
    ": Addressbook", ": Kill letter", NULL,
    ": move to Different area", ": Save messages", NULL,
    ": Edit letter", NULL, ": Back to area list"
  };

  // special treatment for index 1
  if (bm.areaList->supportedMSF() & MSF_MARKED)
  {
    keys[1] = "M";
    func[1] = ": Mark/unmark letter";
  }
  else keys[1] = func[1] = NULL;

  // special treatment for index 2
  if (bm.areaList->supportedMSF() & MSF_READ)
  {
    keys[2] = "U";
    func[2] = ": Unread/read toggle";
  }
  else keys[2] = func[2] = NULL;

  // special treatment for index 4
  if (bm.areaList->isCollection()) keys[4] = func[4] = NULL;
  else
  {
    keys[4] = "O";
    func[4] = ": change sort Order";
  }

  if (bm.areaList->isReplyArea()) newHelpMenu(repkeys, repfunc);
  else newHelpMenu(keys, func);

  menu->delay_update();
}


void HelpWindow::h_letter ()
{
  int i, y = 1;

  static const char *common1[] =
  {
    " #: rot13 decryption",
    " =: quoted-printable decoding",
    " A: Addressbook",
    " C: toggle Character set translation",
    "",
    NULL
  },
  *common2[] =
  {
    "",
    " S: Save letter",
    " V: ANSI Viewer",
    " X: toggle kludge line display",
    " Q: Back to letter list",
    NULL
  },
  *regular[] =
  {
    " D: reply to Different area",
    " E: Enter letter to area",
    " F: Forward letter to area",
    " M: Mark/unmark letter",
    " N: Netmail reply",
    " O: reply to Original sender",
    " R: Reply to letter",
    " T: Tagline management",
    "^T: get Tagline from letter",
    " U: Unread/read toggle",
    NULL
  },
  *reply[] =
  {
    " D: move to Different area",
    " E: Edit letter",
    "^E: Edit letter (body only)",
    " K: Kill letter",
    NULL
  },
  *navigation[] =
  {
    "    Up: Up one line",
    "  Down: Down one line",
    "  PgUp: Up one screen",
    "  PgDn: Down one screen",
    "  Home: Top of letter",
    "   End: End of letter",
    "",
    " Right: Next letter",
    "  Left: Previous letter",
    " Enter: Next letter",
    "",
    " Space: Page through area",
    "   Tab: Next subject",
    NULL
  };

  int l = (bm.areaList->isReplyArea() ? 4 : 10) + 10;

  menu = new ShadowedWin(l + 2, 70, (LINES - l - 2) >> 1, (COLS - 70) >> 1,
                         C_HELPBORDER);

  menu->attrib(C_HELPTEXT);

  for (i = 0; common1[i]; i++) menu->putstring(y++, 2, common1[i]);
  const char **specific = (bm.areaList->isReplyArea() ? reply : regular);
  for (i = 0; specific[i]; i++) menu->putstring(y++, 2, specific[i]);
  for (i = 0; common2[i]; i++) menu->putstring(y++, 2, common2[i]);

  y = l - 13;
  for (i = 0; navigation[i]; i++) menu->putstring(++y, 42, navigation[i]);

  ((ShadowedWin *) menu)->delay_update();
}


void HelpWindow::MakeActive ()
{
  switch (interface->getstate())
  {
    case servicelist:
      h_servicelist();
      break;

    case packetlist:
      h_packetlist();
      break;

    case filedblist:
      h_filedblist();
      break;

    case replymgrlist:
      h_replymgrlist();
      break;

    case arealist:
      h_arealist();
      break;

    case letterlist:
      if (!bm.resourceObject->isYes(FullsizeLetterList)) h_letterlist();
      break;

    case letter_help:
      h_letter();
      break;

    default:
      ;
  }
}


void HelpWindow::Delete ()
{
  switch (interface->getstate())
  {
    case servicelist:
    case packetlist:
    case filedblist:
    case replymgrlist:
    case arealist:
      delete menu;
      break;

    case letterlist:
      if (!bm.resourceObject->isYes(FullsizeLetterList)) delete menu;
      break;

    case letter_help:
      delete (ShadowedWin *) menu;
      break;

    default:
      ;
  }
}
